VERSION 8000
* Achse_AttributeListen.CSX  15.02.10
* -----------------------------------------------------------------------------
* @filedoc
* @file Achse_AttributeListen.CSX
* @brief Achsattribute protokollieren
* 
* Dieses Skript listet fr alle Achsen folgende Attributangaben im Protokoll auf:
* Achsnummer, Achsbezeichnung, Achstyp, Anzahl der Elemente, Nummer der Bezugsachse,
* Nummer der Bezugsgradiente, Nummer der Bezugsberhhung, Anzahl der Fehlstationen.
* Protokolliert wird auch die Anzahl der Achsen im Projekt.
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author CK
* @endfiledoc
* -----------------------------------------------------------------------------
* @history
* -----------------------------------------------------------------------------

* --- Vereinbarungen ----------------------------------------------------------

BILDSCHIRM GRAFIK

* --- Deklarationen -----------------------------------------------------------

SYMBOLE /ALIGNMENTSYS/ AchsSys                     | Symbol fr das System der Achsen
SYMBOLE /ALIGNMENT/ Achse                          | Symbol fr die Achse
SYMBOLE /ALIGNMENTELEMENT/ AElement                | Symbol fr das Achselement

SYMBOLE * I; IE; !AchsBez; AStat; EStat; Type; !Type; BezugA; BezugGrad; Anz_A; Anz_EL; BezugUeb; Fehlstat

* --- Ausfhrungen ------------------------------------------------------------

AchsSys = Project.GetAlignmentSys()                | liefert das Objekt fr das System der Achsen             

* Ausgabe ins Protokoll  
MELDE "-----------------------------"
MELDE " Achsattribute protokollieren"
MELDE "-----------------------------"
MELDE " Achsnr.  Bezeichnung                                 Typ      Achslnge [m] Elemente Bezugsachse Bezugsgradiente berhhung Fehlstationen "
MELDE "--------------------------------------------------------------------------------------------------------------------------------------------"
  
* Schleife ber alle Achsen
Anz_A = 0                                          | Anzahl der Achsen
SCHLEIFE I = 1; 9999

  Achse = AchsSys.GetAlignment(I)                  | liefert das Achsobjekt
  WENN Achse <> $NULL DANN
    !AchsBez = Achse.GetDescription()              | liefert die Achsbezeichnung
    Type = Achse.GetType()                         | liefert den Achstyp
    !Type = !TypeBez_C(Type)                       | Funktionsaufruf: liefert Bezeichnung des Achstyps
    
    * Schleife ber alle Achselemente
    Anz_EL = 0                                     | Anzahl der Achselemente 
    SCHLEIFE IE = 1; 99999 
      AElement = Achse.GetElement(IE)              | liefert das Element der Achse
      WENN AElement == $NULL DANN ABBRUCH SCHLEIFE
      Anz_EL = Anz_EL + 1
    ENDE SCHLEIFE
     
    * Achsattribute ermitteln
    AStat = Achse.GetStartChainage()               | Anfangsstation der Achse
    EStat = Achse.GetEndChainage()                 | Endstation der Achse
    LaengA = EStat - AStat                         | Lnge der Achse  
    BezugA = Achse.GetRefAlignmentId()             | Nummer der Bezugsachse
    BezugGrad = Achse.GetRefVertAlignId()          | Nummer der Bezugsgradiente 
    Bezugueb = Achse.GetRefCantStringId()          | Nummer der Bezugsberhhung 	
    Fehlstat = Achse.GetNumberOfDiscont()          | Anzahl der Fehlstationen

    MELDE " ####   ########################################    ############  ####.###  #####     ####         #####          ####          ####";I;!AchsBez;!Type;LaengA;Anz_EL;BezugA;BezugGrad;Bezugueb;Fehlstat 
    Anz_A = Anz_A + 1  
  WEITER
  
ENDE SCHLEIFE 
  
MELDE "--------------------------------------------------------------------------------------------------------------------------------------------"
MELDE "Anzahl Achsen im Projekt: #"; Anz_A         | Ausgabe der Achsanzahl
MELDE "==============================="   

STOP

* --- Funktionen ------------------------------------------------------------
* @function TypeBez_C
* @brief Bezeichnung des Achstyps liefern
* @param Typ: Typnummer der Achse 
*
* @return !Typ: Bezeichnung des Achstyps als Text
*
FUNKTION !TypeBez_C: Typ
  SYMBOLE * !Typ
  WENN Typ == 0 DANN !Typ = "unbestimmt"
  WENN Typ == 1 DANN !Typ = "Strae"
  WENN Typ == 2 DANN !Typ = "Eisenbahn"
  WENN Typ == 3 DANN !Typ = "Kanal"
  WENN Typ == 4 DANN !Typ = "Magnetbahn"
  WENN Typ == 5 DANN !Typ = "Straenbahn"
  WENN Typ == 6 DANN !Typ = "Wasserstrae"
  WENN Typ == 7 DANN !Typ = "Deich"
  WENN Typ == 8 DANN !Typ = "Hilfsachse"
  ZURCK !Typ
ENDE FUNKTION
* -----------------------------------------------------------------------------


